.. Serilux documentation master file

Serilux Documentation
========================

Welcome to Serilux's documentation!

Serilux is a powerful, flexible serialization framework for Python objects with
automatic type registration and validation.

.. grid:: 2
   :gutter: 2
   :margin: 2

   .. grid-item-card::
      :link: introduction
      :link-type: doc
      
      **Getting Started**
      
      Learn the basics and key concepts of Serilux.

   .. grid-item-card::
      :link: quickstart
      :link-type: doc
      
      **Quick Start**
      
      Get up and running with Serilux in minutes.

   .. grid-item-card::
      :link: user_guide/index
      :link-type: doc
      
      **User Guide**
      
      Comprehensive guide to using Serilux features.

   .. grid-item-card::
      :link: api_reference/index
      :link-type: doc
      
      **API Reference**
      
      Complete API documentation for all classes and methods.

.. toctree::
   :maxdepth: 2
   :caption: Documentation
   :hidden:

   introduction
   installation
   quickstart
   user_guide/index
   api_reference/index
   examples/index
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

